@@ -17,8 +17,6 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-#ifdef WITH_MIDGARD
-
 #include "../../conboy_note.h"
 #include "../../conboy_storage_plugin.h"
 #include "../../metadata.h"
@@ -387,7 +385,7 @@ conboy_midgard_storage_plugin_init (ConboyMidgardStoragePlugin *self)
 			"database", "ConboyNotes",
 			"dbuser", "midgard",
 			"dbpass", "midgard",
-			"sharedir", "/usr/share/midgard-2.0", NULL);
+			"sharedir", "/usr/share/midgard2", NULL);
 
 	midgard_config_save_file (config, "ConboyNotesStorage", TRUE, NULL);
 
@@ -398,7 +396,7 @@ conboy_midgard_storage_plugin_init (ConboyMidgardStoragePlugin *self)
 
 	midgard_connection_set_loglevel (mgd_global, "debug", NULL);
 
-	gchar *db_file_exists = g_build_path (G_DIR_SEPARATOR_S, g_get_home_dir(), ".midgard-2.0/.conboy_db_exists", NULL);
+	gchar *db_file_exists = g_build_path (G_DIR_SEPARATOR_S, g_get_home_dir(), ".midgard2/.conboy_db_exists", NULL);
 
 	/* Check if database already exists */
 	if (g_file_test (db_file_exists, G_FILE_TEST_EXISTS)) { /* HACK */
@@ -429,8 +427,7 @@ conboy_midgard_storage_plugin_init (ConboyMidgardStoragePlugin *self)
 }
 
 ConboyMidgardStoragePlugin*
-conboy_plugin_new() {
+conboy_plugin_new () 
+{
 	return g_object_new(CONBOY_TYPE_MIDGARD_STORAGE_PLUGIN, NULL);
 }
-
-#endif /* WITH_MIDGARD */
